@@ -8,13 +8,14 @@ from sanic import Sanic
 
 from insanic.config import DEFAULT_CONFIG
 from insanic.db import init_db_connection, close_db_connection
+from insanic.http import Request
 
 class Application(Sanic):
     def __init__(self, *args: Any, **kwargs: Any):
         # @TODO: Implement custom error handler
         # @TODO: Implement proper logging
-        # @TODO: Implement custom Request class
         kwargs['strict_slashes'] = True
+        kwargs['request_class'] = Request  # Setting up custom Request class
         super().__init__(*args, **kwargs)
 
         self.load_configuration()
