@@ -33,10 +33,9 @@ async def init_db_connection() -> BaseDBAsyncClient:
             blueprint_models[blueprint_name] = [f'{blueprint_name}.models']
 
     # @TODO: Fix this ugly hack. Tortoise doesn't like empty modules so we trick it
-    if len(blueprint_models.keys()) == 0:
-        blueprint_models = {'models': {}}
+    # empty_models: dict[str, dict] = {'models': {}}
 
-    await Tortoise.init(db_url=database_url, modules=blueprint_models)
+    await Tortoise.init(db_url=database_url, modules=blueprint_models or None)  # type: ignore
     return get_db_connection()
 
 async def close_db_connection() -> None:
