@@ -1,7 +1,7 @@
 from http import HTTPStatus as HTTP_STATUS
 from typing import Any
 
-from sanic.http import Request as SanicRequest
+from sanic.request import Request as SanicRequest
 from sanic.response import BaseHTTPResponse, HTTPResponse
 
 __all__ = (
